@@ -26,7 +26,7 @@ sub prehook_sysopen {
 sub _install_open; # Provided by open.xs
 sub _install_sysopen; # Provided by open.xs
 
-our $VERSION = '0.02';
+our $VERSION = '1.00.0';
 XSLoader::load( 'overload::open', $VERSION );
 _install_open("OP_OPEN");
 _install_sysopen("OP_SYSOPEN");
@@ -41,29 +41,35 @@ overload::open - Hooks the native open function
 
 =head1 SYNOPSIS
 
+  use overload::open;
   my %opened_files;
-  sub my_callback { return if !@_; $opened_files{shift}++ }
-  use overload::open 'my_callback';
-
+  sub my_callback { return if @_ != 2 && @_ != 3; $opened_files{$_[-1]}++ }
+  overload::open->prehook_open(\&my_callback);
   open my $fh, '>', "foo.txt";
 
 =head1 DESCRIPTION
 
-This module hooks the native C<open()> and/or C<sysopen()> functions and passes the
-arguments first to your function and then calls sends it
-to the provided subroutine functions instead.
-It does this using XS and replacing the OP_OPEN/OP_SYSOPEN opcode's with an XS
-function. This function will call your provided sub, then once that returns
-it will run the original OP.
+This module hooks the native C<open()> and/or C<sysopen()> functions and passes
+the arguments first to callback you provide. It then calls the native open/sysopen.
 
-This function I<should> work fine if you call C<open> or C<sysopen> inside the callback.
+It does this using the XS API and replacing the OP_OPEN/OP_SYSOPEN opcode's
+with an XS function. This function will call your provided sub, then once that
+returns it will run the original OP.
 
-You are not allowed to pass XS subs as the callback because then this could result
-in a recursive loop. If you need to do this, wrap the XS function in a native Perl
-function.
+=head1 FEATURES
+
+This function will work fine if you call C<open> or C<sysopen> inside the
+callback due to it detecting recursive calls and not calling the callback for
+recursive calls.
+
+You are not allowed to pass XS subs as the callback because then this could
+result in a recursive loop. If you need to do this, wrap the XS function in a
+native Perl function.
 
 =head1 METHODS
 
+=over
+
 =item prehook_open
 
   use overload::open
@@ -80,6 +86,8 @@ will be passed the same arguments as open.
 Runs a hook before C<sysopen> by hooking C<OP_SYSOPEN>. Passes the same arguments
 to the provided sub reference as provided to sysopen.
 
+=back
+
 =head1 AUTHOR
 
 Samantha McVey <samantham@posteo.net>
